#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_federated_monsters
----------------------------------

Tests for ``federated_monsters`` module.
"""

import unittest

from federated_monsters import federated_monsters


class TestFederatedMonsters(unittest.TestCase):

    def set_up(self):
        pass

    def test_something(self):
        pass

    def tear_down(self):
        pass

if __name__ == '__main__':
    unittest.main()
